@@ -106,6 +106,14 @@ static const char* armPartId2name(uint32_t partId)
     case 0xd80: return "Cortex-A520";
     case 0xd81: return "Cortex-A720";
     case 0xd82: return "Cortex-X4";
+    case 0xd83: return "Neoverse-V3AE";
+    case 0xd84: return "Neoverse-V3";
+    case 0xd85: return "Cortex-X925";
+    case 0xd87: return "Cortex-A725";
+    case 0xd88: return "Cortex-A520AE";
+    case 0xd89: return "Cortex-A720AE";
+    case 0xd8e: return "Neoverse-N3";
+    case 0xd8f: return "Cortex-A320";
     default: return NULL;
     }
 }
@@ -165,7 +173,8 @@ static const char* qcomPartId2name(uint32_t partId)
 {
     switch (partId)
     {
-    case 0x001: return "Oryon";
+    case 0x001: return "Oryon 1";
+    case 0x002: return "Oryon 2";
     case 0x00f: return "Scorpion";
     case 0x02d: return "Scorpion";
     case 0x04d: return "Krait";
@@ -259,6 +268,9 @@ static const char* applePartId2name(uint32_t partId)
     case 0x037: return "Everest-A16";
     case 0x038: return "Blizzard-M2-Max";
     case 0x039: return "Avalanche-M2-Max";
+    case 0x046: return "Sawtooth-M11";
+    case 0x048: return "Sawtooth-M3-Max";
+    case 0x049: return "Everest-M3-Max";
     default: return NULL;
     }
 }
@@ -307,6 +319,7 @@ static const char* fujitsuPartId2name(uint32_t partId)
     switch (partId)
     {
     case 0x001: return "A64FX";
+    case 0x003: return "MONAKA";
     default: return NULL;
     }
 }
