@@ -37,6 +37,10 @@ static bool isPhysicalDevice(const struct mntent* device)
     if(ffStrEquals(device->mnt_type, "zfs"))
         return true;
 
+    //sshfs
+    if(ffStrEquals(device->mnt_type, "fuse.sshfs"))
+        return true;
+
     //Pseudo filesystems don't have a device in /dev
     if(!ffStrStartsWith(device->mnt_fsname, "/dev/"))
         return false;
@@ -279,7 +283,7 @@ const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
 
     while((device = getmntent(mountsFile)))
     {
-        if (__builtin_expect(options->folders.length, 0))
+        if (__builtin_expect(options->folders.length > 0, false))
         {
             if (!ffDiskMatchMountpoint(&options->folders, device->mnt_dir))
                 continue;
